@@ -1,5 +1,5 @@
 <?php
-/* $Id: chinese_traditional-utf-8.inc.php 9380 2006-08-30 10:43:15Z nijel $ */
+/* $Id: chinese_traditional-utf-8.inc.php 11113 2008-02-09 16:09:54Z lem9 $ */
 
 /**
  * Last translation by: Siu Sun <siusun@best-view.net>
@@ -25,7 +25,6 @@ $datefmt = '%B %d, %Y, %I:%M %p';
 $timespanfmt = '%s 日, %s 小時, %s 分鐘 %s 秒';
 
 $strAbortedClients = '取消';
-$strAbsolutePathToDocSqlDir = '請輸入 docSQL 目錄於網頁伺服器的絕對路徑';
 $strAccessDenied = '拒絕存取';
 $strAccessDeniedCreateConfig = '有可能你未建立設定檔. 你可利用此 %1$s安裝程序%2$s 建立設定檔.';
 $strAccessDeniedExplanation = 'phpMyAdmin 嘗試連線到 MySQL 伺服器, 但伺服器拒絕了連線. 您應於 config.inc.php 內檢查主機名稱, 登入名稱及密碼及確保這些資料是與系統管理人員所提供的 MySQL 伺服器資料相同';
@@ -34,8 +33,6 @@ $strAddAutoIncrement = "新增 AUTO_INCREMENT 數值";
 $strAddConstraints = '加入限制';
 $strAddDeleteColumn = '新增/減少 選擇欄';
 $strAddDeleteRow = '新增/減少 篩選列';
-$strAddedColumnComment = '於以下欄位加入註解文字';
-$strAddedColumnRelation = '於以下欄位加入關聯';
 $strAddFields = '新增 %s 個欄位';
 $strAddHeaderComment = '於標題加入個人註解 (\\n 開新行)';
 $strAddIntoComments = '加入註解文字';
@@ -71,7 +68,6 @@ $strAscending = '遞增';
 $strAtBeginningOfTable = '於資料表開頭';
 $strAtEndOfTable = '於資料表尾端';
 $strAttr = '屬性';
-$strAutodetect = '自動偵測';
 $strAutomaticLayout = '自動格式';
 
 $strBack = '回上一頁';
@@ -177,8 +173,6 @@ $strCreationDates = '建立/更新/檢查 日期';
 $strCriteria = '篩選';
 $strCroatian = '克羅西亞語';
 $strCSV = 'CSV';  //USE ENG
-$strCSVImportOptions = 'CSV 選項';
-$strCSVOptions = 'CSV 選項';
 $strCyrillic = '西里爾語';
 $strCzech = '捷克語';
 $strCzechSlovak = '捷克語';
@@ -189,7 +183,6 @@ $strDatabase = '資料庫';
 $strDatabaseEmpty = '資料庫名稱並未輸入!!';
 $strDatabaseExportOptions = '資料庫輸出選項';
 $strDatabaseHasBeenDropped = '資料庫 %s 已被刪除';
-$strDatabaseNoTable = '這資料庫沒有資料表!';
 $strDatabases = '資料庫';
 $strDatabasesDropped = '%s 個資料庫已成功刪除.';
 $strDatabasesStats = '資料庫統計';
@@ -201,15 +194,6 @@ $strDataOnly = '只有資料';
 $strDataPages = '包含資料頁';
 $strDBComment = '資料庫註解文字: ';
 $strDBCopy = '複製資料庫到';
-$strDBGContext = '本文 (Context)';
-$strDBGContextID = '本文 (Context) ID';
-$strDBGHits = '次數';
-$strDBGLine = '行';
-$strDBGMaxTimeMs = '最大時間, ms';
-$strDBGMinTimeMs = '最小時間, ms';
-$strDBGModule = '模組';
-$strDBGTimePerHitMs = '時間/次, ms';
-$strDBGTotalTimeMs = '總時間, ms';
 $strDbPrivileges = '指定資料庫權限';
 $strDBRename = '更改資料庫名稱到';
 $strDbSpecific = '指定資料庫';
@@ -269,7 +253,6 @@ $strEscapeWildcards = '萬用符號 _ 及 % 應正確地加入 \ ';
 $strEsperanto = '世界語';
 $strEstonian = '愛沙尼亞語';
 $strExcelEdition = 'Excel 版本';
-$strExcelOptions = 'Excel 選項';
 $strExecuteBookmarked = '執行書籤查詢';
 $strExplain = '說明 SQL';
 $strExport = '輸出';
@@ -280,7 +263,6 @@ $strFailedAttempts = '嘗試失敗';
 $strField = '欄位';
 $strFieldHasBeenDropped = '資料表 %s 已被刪除';
 $strFields = '欄位';
-$strFieldsEmpty = ' 欄位總數是空的! ';
 $strFieldsEnclosedBy = '「欄位」使用字元：';
 $strFieldsEscapedBy = '「ESCAPE」使用字元：';
 $strFieldsTerminatedBy = '「欄位分隔」使用字元：';
@@ -323,15 +305,12 @@ $strHasBeenAltered = '已經修改';
 $strHasBeenCreated = '已經建立';
 $strHaveToShow = '您需要選擇最少顯示一行欄位';
 $strHebrew = '希伯來語';
-$strHexForBinary = '以十六進制數值顯示二進制欄位';
 $strHome = '主目錄';
 $strHomepageOfficial = 'phpMyAdmin 官方網站';
 $strHost = '主機';
 $strHostEmpty = '請輸入主機名稱!';
 $strHTMLExcel = 'Microsoft Excel 2000';
-$strHTMLExcelOptions = 'Microsoft Excel 2000 輸出選項';
 $strHTMLWord = 'Microsoft Word 2000';
-$strHTMLWordOptions = 'Microsoft Word 2000 輸出選項';
 $strHungarian = '匈牙利語';
 
 $strIcelandic = '冰島語'; 
@@ -340,9 +319,7 @@ $strIdxFulltext = '全文檢索';
 $strIgnore = '忽略';
 $strIgnoreDuplicates = '略過重覆列';
 $strIgnoreInserts = '使用忽略加入 (insert)'; 
-$strIgnoringFile = '忽略檔案 %s';
 $strImport = '載入';
-$strImportDocSQL = '讀取 docSQL 檔案';
 $strImportFiles = '輸入檔案';
 $strImportFormat = '載入檔案格式';
 $strImportSuccessfullyFinished = '載入成功, 共 %d 句語法已執行.';
@@ -351,10 +328,7 @@ $strIndexes = '索引';
 $strIndexHasBeenDropped = '索引 %s 已被刪除';
 $strIndexName = '索引名稱&nbsp;:';
 $strIndexType = '索引類型&nbsp;:';
-$strIndexWarningMultiple = '多過一個 %s 鍵已建立到欄位 `%s` 中';
-$strIndexWarningPrimary = '主鍵 PRIMARY 及 索引鍵 INDEX 不應同時間設定欄位 `%s` 中';
 $strIndexWarningTable = '於資料表 `%s` 中有索引問題';
-$strIndexWarningUnique = '唯一鍵 UNIQUE 及 索引鍵 INDEX 不應同時間設定欄位 `%s` 中';
 $strInnoDBAutoextendIncrement = '自動伸延大小';
 $strInnoDBAutoextendIncrementDesc = '當資料表容量接近滿時, 自動增大容量的大小.';
 $strInnoDBBufferPoolSize = '緩衝區大小';
@@ -398,7 +372,6 @@ $strKill = 'Kill'; //should expressed in English
 $strKorean = '韓語';
 
 $strLandscape = '橫向';
-$strLanguageFileNotFound = '找不到語言檔案 "%1$s".';
 $strLanguageUnknown = '不知名語言: %1$s.';
 $strLatchedPages = '鎖上頁';
 $strLaTeX = 'LaTeX';  // use eng
@@ -408,11 +381,9 @@ $strLatexContinued = '(連續)';
 $strLatexContinuedCaption = '連續資料表標題';
 $strLatexIncludeCaption = '包括資料表標題';
 $strLatexLabel = '標記鍵名';
-$strLaTeXOptions = 'LaTeX 選項';
 $strLatexStructure = '資料表 __TABLE__ 結構';
 $strLatvian = '拉脫維亞語';
 $strLDI = 'CSV 使用 LOAD DATA';
-$strLDIImportOptions = 'CSV 輸入使用 LOAD DATA 選項';
 $strLDILocal = '使用 LOCAL 關鍵字';
 $strLengthSet = '長度/集合*';
 $strLimitNumRows = '筆記錄/每頁';
@@ -443,7 +414,7 @@ $strMIME_nodescription = '這個轉換方式沒有說明.<br />請向作者查
 $strMIME_transformation = '瀏覽器轉換方式';
 $strMIME_transformation_note = '有關可使用之轉換方式選項及 MINE 類型轉換選項, 請查看 %s轉換方式說明%s';
 $strMIME_transformation_options = '轉換方式選項';
-$strMIME_transformation_options_note = '請用以下的格式輸入轉換選項值: \'a\',\'b\',\'c\'...<br />如您需要輸入反斜線 ("\") 或單引號 ("\'") 請再加上反斜線 (例如 \'\\\\xyz\' or \'a\\\'b\').';
+$strMIME_transformation_options_note = '請用以下的格式輸入轉換選項值: \'a\', 100, b,\'c\'...<br />如您需要輸入反斜線 ("\") 或單引號 ("\'") 請再加上反斜線 (例如 \'\\\\xyz\' or \'a\\\'b\').';
 $strMIME_without = 'MIME 類型以斜體顯示是沒有分隔轉換功能';
 $strMIMETypesForTable = 'MIME TYPES FOR TABLE';  // keep in SQL statement
 $strModifications = '修改已儲存';
@@ -533,7 +504,6 @@ $strPDF = 'PDF';  // USE ENG
 $strPdfDbSchema = '"%s" 資料庫概要 - 第 %s 頁';
 $strPdfInvalidTblName = '資料表 "%s" 不存在!';
 $strPdfNoTables = '沒有資料表';
-$strPDFOptions = 'PDF 選項';
 $strPDFReportTitle = '報告標題';
 $strPerHour = '每小時';
 $strPerMinute = '每分鐘';
@@ -721,8 +691,6 @@ $strSplitWordsWithSpace = '每組文字以空格 (" ") 分隔.';
 $strSQL = 'SQL'; // should express in english
 $strSQLCompatibility = 'SQL 兼容模式';
 $strSQLExportType = '輸出方式';
-$strSQLImportOptions = 'SQL 選項';
-$strSQLOptions = 'SQL 選項';
 $strSQLParserBugMessage = '這可能是您找到了 SQL 分析程式的一些程式錯誤，請細心查看您的語法，檢查一下引號是正確及沒有遺漏，其他可能出錯的原因可能來自您上載檔案時在引號外的地方使用了二進制碼。您可以嘗試在 MySQL 命令列介面執行該語法。如 MySQL 伺服器發出錯誤信息，這可能幫助您去找出問題所在。如您仍然未能解決問題，或在分析程式出現錯誤，但在命令列模式能正常執行，請將該句出現錯誤的 SQL 語法抽出，並將以下的"剪取"部份一同提交到臭虫區:';
 $strSQLParserUserError = '可能是您的 SQL 語法出現錯誤，如 MySQL 伺服器發出錯誤信息，這可能幫助您去找出問題所在。';
 $strSQLQuery = 'SQL 語法';
@@ -776,7 +744,6 @@ $strThemeNotFound = '找不到佈景主題 %s !';
 $strThemeNoValidImgPath = '找不到佈景主題 %s 設定圖像之路徑!';
 $strThemePathNotFound = '找不到佈景主題 %s 之設定路徑!';
 $strThisHost = '指定主機';
-$strThisNotDirectory = '這並不是一個目錄';
 $strThreads = '線程';
 $strThreadSuccessfullyKilled = '指令 %s 已成功中止.';
 $strTime = '時間';
@@ -792,7 +759,6 @@ $strTransformation_application_octetstream__hex = '以十六進制方式顯示.'
 $strTransformation_image_jpeg__inline = '顯示可按式圖像; 選項; 寬度,高度[以像素為單位] (保時原有比例)';
 $strTransformation_image_jpeg__link = '顯示圖像的連線 (直接下載).';
 $strTransformation_image_png__inline = '參看 image/jpeg: 內建';
-$strTransformation_text_plain__dateformat = '使用 TIME, TIMESTAMP 或 DATETIME 並以本地時區時間顯示. 第一個選項是修正 (以小時為單位) 來調整顯示之時間 (預設: 0). 第二個選項是日期格式 [跟據 PHPs strftime() 的參數].';
 $strTransformation_text_plain__external = '只限於 LINUX : 執行外部程式及將內容以標準輸入模式輸入. 輸出程式之標準輸出. 預設是整齊的, 方便顯示 HTML 碼. 由於保安理由, 您需要自行編輯 libraries/transformations/text_plain__external.inc.php 及加入需要使用工具作為執行. 第一個選項為有多少個程式需要使用, 第二個選項為這式程式的參數, 第三個選項, 如設定為 1 將會使用 htmlspecialchars() 轉換輸出 (預設: 1). 第四個選項, 如設定為 1 將會加入 NOWRAP 於內容的表格內, 令輸出之所有內容都不會重新排位 (預設: 1)';
 $strTransformation_text_plain__formatted = '保存原本內容之格式. 不進行任何 Escaping 處理.';
 $strTransformation_text_plain__imagelink = '顯示圖像及連結, 數據內容是檔案名稱; 第一個選項是網址前段 (例 "http://domain.com/" ), 第二個選項是寬度的像素,第三個選項是高度的像素.';
@@ -852,8 +818,6 @@ $strWildcard = '萬用字元';
 $strWindowNotFound = '目地的視窗無法更新. 可能你已關閉此視窗或你的瀏覽器於安全設定內啟動了無法跨視窗更新';
 $strWithChecked = '選擇的資料表：';
 $strWriteRequests = '寫入要求';
-$strWritingCommentNotPossible = '無法儲存註解文字';
-$strWritingRelationNotPossible = '無法儲存關聯';
 $strWrongUser = '錯誤的使用者名稱或密碼，拒絕存取';
 
 $strXML = 'XML'; //USE ENG
@@ -939,7 +903,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
 $strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
@@ -981,16 +945,12 @@ $strUnsupportedCompressionDetected = 'You attempted to load file with unsupporte
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -1003,4 +963,74 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
+$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
 ?>
