@@ -1,5 +1,5 @@
 <?php
-/* $Id: latvian-utf-8.inc.php 9261 2006-08-09 12:55:40Z lem9 $ */
+/* $Id: latvian-utf-8.inc.php 11113 2008-02-09 16:09:54Z lem9 $ */
 
 /**
  * Latvian language file by Sandis Jērics <sandisj at parks.lv>
@@ -8,7 +8,7 @@
 $charset = 'utf-8';
 $allow_recoding = TRUE;
 $text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
-$number_thousands_separator = ' ';
+$number_thousands_separator = ' ';
 $number_decimal_separator = '.';
 // shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
 $byteUnits = array('baiti', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
@@ -22,7 +22,6 @@ $datefmt = '%d.%m.%Y %H:%M';
 $timespanfmt = '%s dienas, %s stundas, %s minūtes un %s sekundes';
 
 $strAbortedClients = 'Pārtraukts';
-$strAbsolutePathToDocSqlDir = 'Lūdzu ievadiet absolūto ceļu līdz docSQL direktorijai uz servera';
 $strAccessDeniedExplanation = 'phpMyAdmin mēģināja pieslēgties MySQL serverim, un serveris noraidīja pieslēgumu. Lūdzu pārbaudiet hostu, lietotājvārdu un paroli config.inc.php failā, un pārliecinieties, ka tie atbilst informācijai, ko Jums deva MySQL servera administrators.';
 $strAccessDenied = 'Pieeja aizliegta';
 $strAction = 'Darbība';
@@ -30,8 +29,6 @@ $strAddAutoIncrement = 'Pievienot AUTO_INCREMENT vērtību';
 $strAddConstraints = 'Pievienot ierobežojumus';
 $strAddDeleteColumn = 'Pievienot/Dzēst laukus (kolonnas)';
 $strAddDeleteRow = 'Pievienot/Dzēst ierakstu';
-$strAddedColumnComment = 'Pievienots komentārs kolonnai';
-$strAddedColumnRelation = 'Pievienota relācija kolonnai';
 $strAddFields = 'Pievienot %s lauku(s)';
 $strAddHeaderComment = 'Ievietot virsrakstā komentāru (\\n atdala rindas)';
 $strAddIntoComments = 'Pievienot komentāros';
@@ -65,7 +62,6 @@ $strAscending = 'Augošā secībā';
 $strAtBeginningOfTable = 'Tabulas sākumā';
 $strAtEndOfTable = 'Tabulas beigās';
 $strAttr = 'Atribūti';
-$strAutodetect = 'Noteikt automātiski';
 $strAutomaticLayout = 'Automātiskais izvietojums';
 
 $strBack = 'Atpakaļ';
@@ -154,7 +150,6 @@ $strCreatePdfFeat = 'PDF failu izveide';
 $strCreationDates = 'Izveidošanas/Atjaunošanas/Piekļuves datumi';
 $strCriteria = 'Kritērijs';
 $strCroatian = 'Horvātu';
-$strCSVOptions = 'CSV opcijas';
 $strCyrillic = 'Kirilisks';
 $strCzech = 'Čehu';
 $strCzechSlovak = 'Čehu-Slovāku';
@@ -164,7 +159,6 @@ $strDatabase = 'Datubāze';
 $strDatabaseEmpty = 'Datubāzes nosaukums ir tukšs!';
 $strDatabaseExportOptions = 'Datubāzu eksporta opcijas';
 $strDatabaseHasBeenDropped = 'Datubāze %s tika izdzēsta.';
-$strDatabaseNoTable = 'Šajā datubāzē nav tabulu!';
 $strDatabases = 'Datubāzes';
 $strDatabasesDropped = '%s datubāzes tika veiksmīgi dzēstas.';
 $strDatabasesStats = 'Datubāzu statistika';
@@ -176,15 +170,6 @@ $strDataDict = 'Datu vārdnīca';
 $strDataOnly = 'Tikai dati';
 $strDBComment = 'Datubāzes komentārs: ';
 $strDBCopy = 'Kopēt datubāzi uz';
-$strDBGContextID = 'Konteksta ID';
-$strDBGContext = 'Konteksts';
-$strDBGHits = 'Apmeklējumi';
-$strDBGLine = 'Līnija';
-$strDBGMaxTimeMs = 'Maks. laiks, ms';
-$strDBGMinTimeMs = 'Min. laiks, ms';
-$strDBGModule = 'Modulis';
-$strDBGTimePerHitMs = 'Viena apmeklējuma laiks, ms';
-$strDBGTotalTimeMs = 'Laiks kopā, ms';
 $strDbPrivileges = 'Datubāžu specifiskās privilēģijas';
 $strDBRename = 'Pārsaukt datubāzi par';
 $strDbSpecific = 'datubāzei specifisks';
@@ -235,7 +220,6 @@ $strError = 'Kļūda';
 $strEscapeWildcards = 'Aizstājējzīmes _ un % jāaizsargā ar \ priekšā, lai izmantotu tās burtiski';
 $strEstonian = 'Igauņu';
 $strExcelEdition = 'Excel redakcija';
-$strExcelOptions = 'Excel opcijas';
 $strExecuteBookmarked = 'Izpildīt iegrāmatoto vaicājumu';
 $strExplain = 'Izskaidrot SQL';
 $strExport = 'Eksports';
@@ -245,7 +229,6 @@ $strExtra = 'Ekstras';
 $strFailedAttempts = 'Neveiksmīgi mēģinājumi';
 $strFieldHasBeenDropped = 'Lauks %s tika izdzēsts';
 $strField = 'Lauks';
-$strFieldsEmpty = ' Lauku skaits ir nulle! ';
 $strFieldsEnclosedBy = 'Lauki iekļauti iekš';
 $strFieldsEscapedBy = 'Glābjoša (escape) rakstzīme ir';
 $strFields = 'Lauki';
@@ -279,7 +262,6 @@ $strHasBeenAltered = 'tika modificēta.';
 $strHasBeenCreated = 'tika izveidota.';
 $strHaveToShow = 'Izvēlieties vismaz vienu kolonnu attēlošanai';
 $strHebrew = 'Ebreju';
-$strHexForBinary = 'Lietot heksadecimālo formātu binārajiem laukiem';
 $strHomepageOfficial = 'Oficiālā phpMyAdmin mājaslapa';
 $strHome = 'Sākumlapa';
 $strHostEmpty = 'Hosts nav norādīts!';
@@ -291,18 +273,13 @@ $strId = 'ID';
 $strIdxFulltext = 'Pilni teksti';
 $strIgnore = 'Ignorēt';
 $strIgnoreInserts = 'Lietot IGNORE INSERTS';
-$strIgnoringFile = 'Ignorējam failu %s';
-$strImportDocSQL = 'Importēt docSQL failus';
 $strImportFiles = 'Importēt failus';
 $strIndexes = 'Indeksi';
 $strIndexHasBeenDropped = 'Indekss %s tika izdzēsts';
 $strIndex = 'Indekss';
 $strIndexName = 'Indeksa nosaukums&nbsp;:';
 $strIndexType = 'Indeksa tips&nbsp;:';
-$strIndexWarningMultiple = 'Vairāk kā viena %s atslēga tika izveidota kolonnai `%s`';
-$strIndexWarningPrimary = 'PRIMARY un INDEX atslēgas nevar abas reizē tikt uzliktas kolonnai `%s`';
 $strIndexWarningTable = 'Problēmas ar indeksiem tabulā `%s`';
-$strIndexWarningUnique = 'UNIQUE un INDEX atslēgas nevar abas reizē tikt uzliktas kolonnai `%s`';
 $strInnodbStat = 'InnoDB statuss';
 $strInsecureMySQL = 'Jūsu konfigurācijas fails satur iestādījumus (lietotājs "root" bez paroles), kas atbilst noklusētajam MySQL priviliģētajam lietotājam. Jūsu MySQL serveris strādā ar šo noklusēto variantu, ir atvērts uzbrukumiem, un Jums tiešām jāaiztaisa šis drošības caurums.';
 $strInsertAsNewRow = 'Ievietot kā jaunu rindu';
@@ -331,7 +308,6 @@ $strLatexContinued = '(turpinājums)';
 $strLatexIncludeCaption = 'Iekļaut tabulas virsrakstu';
 $strLatexLabel = 'Etiķetes atslēga';
 $strLaTeX = 'LaTeX';
-$strLaTeXOptions = 'LaTeX opcijas';
 $strLatexStructure = 'Tabulas __TABLE__ struktūra';
 $strLatvian = 'Latviešu';
 $strLengthSet = 'Garums/Vērtības*';
@@ -356,7 +332,7 @@ $strMIME_description = 'Apraksts';
 $strMIME_MIMEtype = 'MIME tips';
 $strMIME_nodescription = 'Šai transformācijai nav apraksta.<br />Jautājiet autoram, ko %s dara.';
 $strMIME_transformation_note = 'Lai iegūtu pieejamo transformāciju opcijas un to MIME tipu transformācijas, uzklikšķiniet uz %stransformāciju apraksti%s';
-$strMIME_transformation_options_note = 'Lūdzu ievadiet transformāciju opciju vērtības, lietojot šo formatu: \'a\',\'b\',\'c\'...<br />Ja Jums jālieto atpakaļējā slīpsvītra ("\") vai vienkāršā pēdiņa ("\'") starp šīm vērtībām, lieciet tās priekšā vēl vienu atpakaļējo slīpsvītru (piemēram \'\\\\xyz\' or \'a\\\'b\').';
+$strMIME_transformation_options_note = 'Lūdzu ievadiet transformāciju opciju vērtības, lietojot šo formatu: \'a\', 100, b,\'c\'...<br />Ja Jums jālieto atpakaļējā slīpsvītra ("\") vai vienkāršā pēdiņa ("\'") starp šīm vērtībām, lieciet tās priekšā vēl vienu atpakaļējo slīpsvītru (piemēram \'\\\\xyz\' or \'a\\\'b\').';
 $strMIME_transformation_options = 'Transformācijas opcijas';
 $strMIME_transformation = 'Pārlūkprogrammas transformācija';
 $strMIMETypesForTable = 'MIME TIPI TABULAI';
@@ -589,7 +565,6 @@ $strSpaceUsage = 'Diska vietas lietošana';
 $strSpanish = 'Spāņu';
 $strSplitWordsWithSpace = 'Vārdi ir atdalīti ar tukšumu (" ").';
 $strSQLExportType = 'Eksporta veids';
-$strSQLOptions = 'SQL opcijas';
 $strSQLParserBugMessage = 'Iespējams, ka Jūs esat atraduši kļūdu SQL interpretatorā. Lūdzu apskatiet Jūsu vaicājumu citīgāk, un pārbaudiet, ka pēdiņas ir pareizas un nav sajauktas. Cits kļūdas iemesls var būt tas, ka Jūs atsūtījāt failu ar bināro vērtību ārpus pēdiņās iekļautā teksta lauka. Jūs varat arī izmēģināt savu vaicājumu MySQL komandrindas interfeisā. MySQL servera kļūdas paziņojums zemāk, ja tāds ir, var arī palīdzēt Jums diagnosticēt problēmu. Ja problēma paliek, vai arī iekš phpMyAdmin kļūda ir, bet komandrindā nav, lūdzu samaziniet Jūsu SQL vaicājumu līdz vienkāršam vaicājumam kas izsauc problēmas, un atsūtiet mums ziņojumu par kļūdu, iekļaujot tajā datus no IZGRIEZT sekcijas zemāk:';
 $strSQLParserUserError = 'Izkatās, ka Jūsu SQL vaicajumā ir kļūda. MySQL servera kļūdas pazinojums zemāk, ja tāds ir, var arī palīdzet Jums diagnosticēt problēmu.';
 $strSQLQuery = 'SQL vaicājums';
@@ -634,7 +609,6 @@ $strTextAreaLength = ' Sava garuma dēļ,<br /> šis lauks var būt nerediģēja
 $strThai = 'Taizemiešu';
 $strTheme = 'Tēma / Stils';
 $strThisHost = 'Šis hosts';
-$strThisNotDirectory = 'Tā nebija direktorija';
 $strThreadSuccessfullyKilled = 'Process %s tika veiksmīgi nogalināts.';
 $strTime = 'Laiks';
 $strToggleScratchboard = 'parādīt/noslēpt piezīmju tafeli';
@@ -647,7 +621,6 @@ $strTransformation_application_octetstream__download = 'Rādīt saiti uz lauka b
 $strTransformation_image_jpeg__inline = 'Parāda klikšķināmo sīktēlu; opcijas: platums, augstums pikseļos (saglabājot oriģinālās proporcijas)';
 $strTransformation_image_jpeg__link = 'Parāda linku uz šo attēlu (tieša blob lauka lajuplāde).';
 $strTransformation_image_png__inline = 'Skatīties image/jpeg: kā ierindotu attēlu';
-$strTransformation_text_plain__dateformat = 'Ņem TIME, TIMESTAMP vai DATETIME lauku, un formatē to izmantojot Jūsu lokālo datuma formatu. Pirmā opcija ir nobīde (stundās), kas tiks pievienota timestamp laukam (noklusētā: 0). Otrā opcija ir datuma formats, saskaņā ar PHP finkcijas strftime() parametriem.';
 $strTransformation_text_plain__external = 'Tikai LINUX: Palaiž ārējo aplikāciju un padod lauka datus tās standartievadā. Atgriež aplikācijas standartizvadi. Noklusējums ir Tidy, kas izskaistina HTML kodu. Drošības apsvērumu dēļ, nepieciešams manuāli rediģēt failu libraries/transformations/text_plain__external.inc.php un ielikt rīkus, kurus Jūs atļaujat palaist. Pirmā opcija ir programmas numurs, ko Jūs vēlaties lietot, otrā opcija ir parametri šai programmai. Trešā opcija, ja ir vienāda ar 1, konvertē izvadi, izmantojot htmlspecialchars() (noklusējums ir 1). Ceturtais parametrs, ja vienāds ar 1, liek NOWRAP parametru satura šūnai, tā kā izvade tiks attēlota bez pārformatēšanas. (noklusējums ir 1)';
 $strTransformation_text_plain__formatted = 'Saglabā lauka oriģinālo formatējumu. Speciālo rakstzīmju pasargāšana netiek veikta.';
 $strTransformation_text_plain__imagelink = 'Parāda attēlu un linku, lauks satur faila nosauumu; pirmā opcija ir prefikss, piemēram, "http://domens.lv/", otrā opcija ir platums pikseļos, trešā ir augstums.';
@@ -699,8 +672,6 @@ $strWestEuropean = 'Rietumeiropas';
 $strWildcard = 'aizstājējzīme';
 $strWindowNotFound = 'Neizdevās atjaunot galveno pārlūkprogramas logu. Varbūt esat viņu aizvēruši, vai arī Jūsu pārlūkprogramma bloķe starplogu saskarsmi Jūsu drošības iestādījumu dēļ.';
 $strWithChecked = 'Ar iezīmēto:';
-$strWritingCommentNotPossible = 'Komentāra rakstīšana nav iespējama';
-$strWritingRelationNotPossible = 'Relācijas rakstīšana nav iespējama';
 $strWrongUser = 'Kļūdains lietotājvārds/parole. Pieeja aizliegta.';
 
 $strXML = 'XML';
@@ -734,7 +705,6 @@ $strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"'
 $strCopy = 'Copy';  //to translate
 $strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
 $strCSV = 'CSV';  //to translate
-$strCSVImportOptions = 'CSV options';  //to translate
 
 $strDataPages = 'Pages containing data';  //to translate
 $strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
@@ -762,9 +732,7 @@ $strGeneratePassword = 'Generate Password';  //to translate
 
 $strHandler = 'Handler';  //to translate
 $strHTMLExcel = 'Microsoft Excel 2000';  //to translate
-$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
 $strHTMLWord = 'Microsoft Word 2000';  //to translate
-$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
 
 $strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
 $strImportFormat = 'Format of imported file';  //to translate
@@ -795,11 +763,9 @@ $strJoins = 'Joins';  //to translate
 
 $strKeyCache = 'Key cache';  //to translate
 
-$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
 $strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
 $strLatchedPages = 'Latched pages';  //to translate
 $strLDI = 'CSV using LOAD DATA';  //to translate
-$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
 $strLDILocal = 'Use LOCAL keyword';  //to translate
 $strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
 
@@ -829,7 +795,6 @@ $strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
 
 $strPagesToBeFlushed = 'Pages to be flushed';  //to translate
 $strPartialImport = 'Partial import';  //to translate
-$strPDFOptions = 'PDF options';  //to translate
 $strPDF = 'PDF';  //to translate
 $strPDFReportTitle = 'Report title';  //to translate
 $strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
@@ -925,7 +890,7 @@ $strShowStatusKey_readsDescr = 'The number of physical reads of a key block from
 $strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
 $strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
 $strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
-$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
+$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAYED queues.';  //to translate
 $strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
 $strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
 $strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
@@ -964,7 +929,6 @@ $strSkipQueries = 'Number of records(queries) to skip from start';  //to transla
 $strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
 $strSorting = 'Sorting';  //to translate
 $strSQLCompatibility = 'SQL compatibility mode';  //to translate
-$strSQLImportOptions = 'SQL options';  //to translate
 $strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
 $strStorageEngines = 'Storage Engines';  //to translate
 $strStorageEngine = 'Storage Engine';  //to translate
@@ -999,16 +963,12 @@ $strQueryResultsOperations = 'Query results operations';  //to translate
 $strAddClause = 'Add %s';  //to translate
 $strUploadsNotAllowed = 'File uploads are not allowed on this server.';  //to translate
 $strOpenDocumentSpreadsheet = 'Open Document Spreadsheet';  //to translate
-$strOpenDocumentSpreadsheetOptions = 'Open Document Spreadsheet options';  //to translate
 $strExportMustBeFile = 'Selected export type has to be saved in file!';  //to translate
-$strXMLOptions = 'XML options';  //to translate
-$strStrucNativeExcelOptions = 'Native Excel export options';  //to translate
 $strCreateUserDatabase = 'Database for user';  //to translate
 $strCreateUserDatabaseNone = 'None';  //to translate
 $strCreateUserDatabaseName = 'Create database with same name and grant all privileges';  //to translate
-$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username_%)';  //to translate
+$strCreateUserDatabaseWildcard = 'Grant all privileges on wildcard name (username\_%)';  //to translate
 $strOpenDocumentText = 'Open Document Text';  //to translate
-$strOpenDocumentTextOptions = 'Open Document Text options';  //to translate
 $strNoDataReceived = 'No data was received to import. Either no file name was submitted, or the file size exceeded the maximum size permitted by your PHP configuration. See FAQ 1.16.';  //to translate
 $strCanNotLoadExportPlugins = 'Could not load export plugins, please check your installation!';  //to translate
 $strErrorRenamingTable = 'Error renaming table %1$s to %2$s';  //to translate
@@ -1021,4 +981,74 @@ $strProcedures = 'Procedures';  //to translate
 $strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate
 $strFontSize = 'Font size';  //to translate
 $strLanguage = 'Language';  //to translate
+$strPmaWiki = 'phpMyAdmin wiki';  //to translate
+$strTransformation_text_plain__dateformat = 'Displays a TIME, TIMESTAMP, DATETIME or numeric unix timestamp field as formatted date. The first option is the offset (in hours) which will be added to the timestamp (Default: 0). Use second option to specify a different date/time format string. Third option determines whether you want to see local date or UTC one (use "local" or "utc" strings) for that. According to that, date format has different value - for "local" see the documentation for PHP\'s strftime() function and for "utc" it is done using gmdate() function.';  //to translate
+$strDocSQL = 'DocSQL';  //to translate
+$strTableName = 'Table name';  //to translate
+$strTableIsEmpty = 'Table seems to be empty!';  //to translate
+$strDbIsEmpty = 'Database seems to be empty!';  //to translate
+$strShowingPhp = 'Showing as PHP code';  //to translate
+$strShowingSQL = 'Showing SQL query';  //to translate
+$strDesigner = 'Designer';  //to translate
+$strNumberOfTables = 'Number of tables';  //to translate
+$strCreateTable  = 'Create table';  //to translate
+$strCreateRelation = 'Create relation';  //to translate
+$strSavePosition = 'Save position';  //to translate
+$strSelectForeignKey = 'Select Foreign Key';  //to translate
+$strHide         = 'Hide';  //to translate
+$strShowHideLeftMenu = 'Show/Hide left menu';  //to translate
+$strReload = 'Reload';  //to translate
+$strSmallBigAll = 'Small/Big All';  //to translate
+$strImportExportCoords = 'Import/Export coordinates for PDF schema';  //to translate
+$strMoveMenu = 'Move Menu';  //to translate
+$strAngularLinks = 'Angular links';  //to translate
+$strDirectLinks = 'Direct links';  //to translate
+$strHideShowAll = 'Hide/Show all';  //to translate
+$strHideShowNoRelation = 'Hide/Show Tables with no relation';  //to translate
+$strInternalRelationAdded = 'Internal relation added';  //to translate
+$strInnoDBRelationAdded = 'InnoDB relation added';  //to translate
+$strRelationDeleted = 'Relation deleted';  //to translate
+$strToSelectRelation = 'To select relation, click :';  //to translate
+$strExportImportToScale = 'Export/Import to scale';  //to translate
+$strRecommended = 'recommended';  //to translate
+$strToFromPage = 'to/from page';  //to translate
+$strSelectReferencedKey = 'Select referenced key';  //to translate
+$strPleaseSelectPrimaryOrUniqueKey = 'Please select the primary key or a unique key';  //to translate
+$strForeignKeyError = 'Error creating foreign key (check data types)';  //to translate
+$strHelp = 'Help';  //to translate
+$strCancel = 'Cancel';  //to translate
+$strDeleteRelation = 'Delete relation';  //to translate
+$strKnownExternalBug = 'The %s functionality is affected by a known bug, see %s';  //to translate
+$strStructureForView = 'Structure for view';  //to translate
+$strStandInStructureForView = 'Stand-in structure for view';  //to translate
+$strToggleSmallBig = 'Toggle small/big';  //to translate
+$strIEUnsupported = 'Internet Explorer does not support this function.';  //to translate
+$strErrorRelationAdded = 'Error: Relation not added.';  //to translate
+$strErrorRelationExists = 'Error: relation already exists.';  //to translate
+$strErrorSaveTable = 'Error saving coordinates for Designer.';  //to translate
+$strSnapToGrid = 'Snap to grid';  //to translate
+$strDesignerHelpDisplayField = 'The display field is shown in pink. To set/unset a field as the display field, click the "Choose field to display" icon, then click on the appropriate field name.';  //to translate
+$strUploadErrorIniSize = 'The uploaded file exceeds the upload_max_filesize directive in php.ini.';  //to translate
+$strUploadErrorFormSize = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';  //to translate
+$strUploadErrorPartial = 'The uploaded file was only partially uploaded.';  //to translate
+$strUploadErrorNoTempDir = 'Missing a temporary folder.';  //to translate
+$strUploadErrorCantWrite = 'Failed to write file to disk.';  //to translate
+$strUploadErrorExtension = 'File upload stopped by extension.';  //to translate
+$strUploadErrorUnknown = 'Unknown error in file upload.';  //to translate
+$strSessionStartupErrorGeneral = 'Cannot start session without errors, please check errors given in your PHP and/or webserver log file and configure your PHP installation properly.';  //to translate
+$strFieldInsertFromFileTempDirNotExists = 'Error moving the uploaded file, see FAQ 1.11';  //to translate
+$strViewName = 'VIEW name';  //to translate
+$strOptions = 'Options';  //to translate
+$strFiles = 'Files';  //to translate
+$strIndexesSeemEqual = 'The following indexes appear to be equal and one of them should be removed:';  //to translate
+$strMysqlLibDiffersServerVersion = 'Your PHP MySQL library version %s differs from your MySQL server version %s. This may cause unpredictable behavior.';  //to translate
+$strRoutines = 'Routines';  //to translate
+$strRoutineReturnType = 'Return type';  //to translate
+$strControluserFailed = 'Connection for controluser as defined in your configuration failed.';  //to translate
+$strHexForBLOB = 'Use hexadecimal for BLOB';  //to translate
+$strRestartInsertion = 'Restart insertion with %s rows';  //to translate
+$strTriggers = 'Triggers';  //to translate
+$strEvent = 'Event';  //to translate
+$strProfiling = 'Profiling';  //to translate
+$strSuhosin = 'Server running with Suhosin. Please refer to %sdocumentation%s for possible issues.';  //to translate
 ?>
